/*
	*
	* CArchiveBranch.cpp - NewBreeze CArchiveBranch Class
	*
*/

#include "carchivebranch.hpp"

CArchiveBranch::CArchiveBranch() : QObject() {

	mPath = QString();
	mIcon = QIcon();

	parentNode = 0;
};

CArchiveBranch::CArchiveBranch( QString name, QIcon icon, QString size, CArchiveBranch *parent ) : QObject()  {

	mPath = QString( name );
	mIcon = icon;
	mSize = size;

	parentNode = parent;
};

int CArchiveBranch::branchCount() {

	return mBranches.count();
};

void CArchiveBranch::clearBranches() {

	mBranches.clear();
};

void CArchiveBranch::addBranch( CArchiveBranch *newNode ) {

	Q_FOREACH( CArchiveBranch* node, mBranches )
		if ( node->name() == newNode->name() )
			return;

	mBranches << newNode;
};

void CArchiveBranch::removeBranch( CArchiveBranch *node ) {

	delete mBranches.takeAt( node->row() );
};

CArchiveBranch* CArchiveBranch::branch( int row ) {

	return mBranches.at( row );
};

CArchiveBranch* CArchiveBranch::branch( QString name ) {

	Q_FOREACH( CArchiveBranch* node, mBranches )
		if ( node->name() == name )
			return node;

	return new CArchiveBranch();
};

QList<CArchiveBranch*> CArchiveBranch::branches() {

	return mBranches;
};

QString CArchiveBranch::name() {

	return mPath;
}

QString CArchiveBranch::size() {

	return mSize;
}

QIcon CArchiveBranch::icon() {

	return mIcon;
};

QVariant CArchiveBranch::data( int role ) const {

	switch( role ) {
		case Qt::DisplayRole:
			return mPath;

		case Qt::DecorationRole:
			return mIcon;

		case Qt::UserRole + 1:
			return mPath;

		default:
			return QVariant();
	}
};

bool CArchiveBranch::setData( int, QVariant ) {

	return true;
};

CArchiveBranch* CArchiveBranch::parent() {

	return parentNode;
};

int CArchiveBranch::row() {

	/* If mPath is not defined */
	if ( not mPath.count() )
		return -1;

	if ( parentNode )
		return parentNode->mBranches.indexOf( this );

	return 0;
};

void CArchiveBranch::sort() {

	std::sort( mBranches.begin(), mBranches.end(), caseInsensitiveNameSort );
};

bool caseInsensitiveNameSort( CArchiveBranch *first, CArchiveBranch *second )  {

	QString name1 = first->name().toLower();
	QString name2 = second->name().toLower();

	return name1 < name2;
};
