/*
	*
	* CArchiveModel.hpp - NewBreeze CArchiveModel Class Header
	*
*/

#pragma once

#include "carchivebranch.hpp"
#include "libarchiveqt.h"

class CArchiveModel : public QAbstractItemModel {
    Q_OBJECT

	public:
		CArchiveModel();
		~CArchiveModel();

		void loadArchive( QString path );

		/* Children Info */
		int rowCount( const QModelIndex &parent = QModelIndex() ) const;
		int columnCount( const QModelIndex &parent = QModelIndex() ) const;

		Qt::ItemFlags flags( const QModelIndex & ) const;

		/* Display Info */
		QVariant data( const QModelIndex &index, int role = Qt::DisplayRole ) const;
		QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;

		/* Node Info */
		QModelIndex index( int row = 0, int column = 0, const QModelIndex &parent = QModelIndex() ) const;
		QModelIndex index( QString, const QModelIndex &parent = QModelIndex() ) const;
		QModelIndex parent( const QModelIndex &index = QModelIndex() ) const;

		/* Children, fetchMore */
		bool hasBranches( const QModelIndex &index = QModelIndex() ) const;

		/* FS Navigation */
		QString nodeName( const QModelIndex ) const;
		QString nodePath( const QModelIndex ) const;
		QString nodePath( QString ) const;
		QFileInfo nodeInfo( const QModelIndex ) const;

	private:
		/* Grow the tree */
		void growTree();

		CArchiveBranch *tree;

		QString archiveName;

	Q_SIGNALS:
		void archiveLoaded();
};

class CNewArchiveModel : public QAbstractItemModel {
    Q_OBJECT

	public:
		CNewArchiveModel();
		~CNewArchiveModel();

		/* Children Info */
		int rowCount( const QModelIndex &parent = QModelIndex() ) const;
		int columnCount( const QModelIndex &parent = QModelIndex() ) const;

		Qt::ItemFlags flags( const QModelIndex & ) const;

		/* Display Info */
		QVariant data( const QModelIndex &index, int role = Qt::DisplayRole ) const;
		QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;

		/* Node Info */
		QModelIndex index( int row = 0, int column = 0, const QModelIndex &parent = QModelIndex() ) const;
		QModelIndex index( QString, const QModelIndex &parent = QModelIndex() ) const;
		QModelIndex parent( const QModelIndex &index = QModelIndex() ) const;

		/* Add (or remove) files to (from) the archive */
		void growTree( QStringList );
		void chopTree( QModelIndexList );

		/* Archive Navigation */
		QString nodeName( const QModelIndex ) const;
		QString nodePath( const QModelIndex ) const;
		QString nodePath( QString ) const;
		QFileInfo nodeInfo( const QModelIndex ) const;

		bool extract( QString ) const;
		bool extractAll() const;

	private:
		/* Grow the tree */
		void plantTree();

		CArchiveBranch *tree;
};
