/*
    *
    * This file is a part of CoreArchiver.
    * Archive manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#ifndef COREARCHIVER_H
#define COREARCHIVER_H

#include <QWidget>
#include <QDir>

#include <cprime/settingsmanage.h>


class CArchiveModel;
class CNewArchiveModel;

namespace Ui {
    class corearchiver;
}

class corearchiver : public QWidget {
    Q_OBJECT

public:
    explicit corearchiver(QWidget *parent = nullptr);
    ~corearchiver();

    void sendFiles(const QStringList &paths);
    void compress();
    void extract();

private Q_SLOTS:
	void loadArchive( QString fileName );
    void on_openArchive_clicked();
    void on_createArchive_clicked();
    void on_addFiles_clicked();
	void on_arcAction_clicked();
	void on_locationTB_clicked();
    void on_removeFile_clicked();

private:
    Ui::corearchiver      *ui;
    QStringList            supportedFormats;
    settingsManage        *sm = settingsManage::initialize();
    int                    uiMode;
    QSize                  listViewIconSize, toolBarIconSize;

    void showArchiveMessage();
    void showExtractMessage();
    void startSetup();
    void loadSettings();
    void loadFiles(const QStringList files);
};

#endif // COREARCHIVER_H
